sqlobject.inheritance.tests.test_indexes module — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests.test_indexes module

class `sqlobject.inheritance.tests.test_indexes.` `InhEmployeeIdxGet`(**kw)

  Bases: `sqlobject.inheritance.tests.test_indexes.InhPersonIdxGet`

  property `age`
  property `childName`
  property `experience`
  property `first_name`
  `j` = inh_employee_idx_get
  property `last_name`
  `q` = inh_employee_idx_get
  `sec_index` = <sqlobject.index.SODatabaseIndex object>
  property `security_number`
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {'InhSalesManIdxGet': <class 'sqlobject.inheritance.tests.test_indexes.InhSalesManIdxGet'>}
    `childName` = 'InhEmployeeIdxGet'
    `indexes` = [<sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_indexes.InhPersonIdxGet`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_indexes.InhEmployeeIdxGet`

    `table` = 'inh_employee_idx_get'

class `sqlobject.inheritance.tests.test_indexes.` `InhPersonIdxGet`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `age`
  property `childName`
  property `first_name`
  `j` = inh_person_idx_get
  property `last_name`
  `pk` = <sqlobject.index.SODatabaseIndex object>
  `q` = inh_person_idx_get
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'InhEmployeeIdxGet': <class 'sqlobject.inheritance.tests.test_indexes.InhEmployeeIdxGet'>}
    `childName` = None
    `indexes` = [<sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_indexes.InhPersonIdxGet`

    `table` = 'inh_person_idx_get'

class `sqlobject.inheritance.tests.test_indexes.` `InhSalesManIdxGet`(**kw)

  Bases: `sqlobject.inheritance.tests.test_indexes.InhEmployeeIdxGet`

  property `experience`
  `j` = inh_sales_man_idx_get
  `q` = inh_sales_man_idx_get
  property `security_number`
  property `skill`
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'InhSalesManIdxGet'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_indexes.InhEmployeeIdxGet`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_indexes.InhSalesManIdxGet`

    `table` = 'inh_sales_man_idx_get'

`sqlobject.inheritance.tests.test_indexes.` `test_index_get_1`()